@@ -2,7 +2,7 @@ from __future__ import absolute_import, division, print_function
 
 from _echopype_version import version as __version__  # noqa
 
-from . import calibrate, preprocess, visualize
+from . import calibrate, preprocess
 from .convert.api import open_raw
 from .echodata.api import open_converted
 from .echodata.combine import combine_echodata
@@ -13,6 +13,5 @@ __all__ = [
     "open_converted",
     "combine_echodata",
     "calibrate",
-    "visualize",
     "preprocess",
 ]
