@@ -338,8 +338,8 @@ def open_raw(
 
         - ``EK60``: Kongsberg Simrad EK60 echosounder
         - ``ES70``: Kongsberg Simrad ES70 echosounder
-        - ``EK80``: Kongsberg Simrad EK80 and Kongsberg EA640 echsoounders
-        - ``EK80``: Kongsberg Simrad EK80 and Kongsberg EA640 echsoounders
+        - ``EK80``: Kongsberg Simrad EK80 echosounder
+        - ``EA640``: Kongsberg EA640 echosounder
         - ``AZFP``: ASL Environmental Sciences AZFP echosounder
         - ``AD2CP``: Nortek Signature series ADCP
           (tested with Signature 500 and Signature 1000)
@@ -432,7 +432,7 @@ def open_raw(
     # Set up echodata object
     echodata = EchoData(source_file=file_chk, xml_path=xml_chk, sonar_model=sonar_model)
     # Top-level date_created varies depending on sonar model
-    if sonar_model in ["EK60", "ES70", "EK80", "ES80"]:
+    if sonar_model in ["EK60", "ES70", "EK80", "ES80", "EA640"]:
         echodata.top = setgrouper.set_toplevel(
             sonar_model=sonar_model, date_created=parser.config_datagram["timestamp"]
         )
@@ -442,12 +442,12 @@ def open_raw(
         )
     echodata.environment = setgrouper.set_env()
     echodata.platform = setgrouper.set_platform()
-    if sonar_model in ["EK60", "ES70", "EK80", "ES80"]:
+    if sonar_model in ["EK60", "ES70", "EK80", "ES80", "EA640"]:
         echodata.nmea = setgrouper.set_nmea()
     echodata.provenance = setgrouper.set_provenance()
     echodata.sonar = setgrouper.set_sonar()
     # Beam_power group only exist if EK80 has both complex and power/angle data
-    if sonar_model == "EK80":
+    if sonar_model in ["EK80", "ES80", "EA640"]:
         echodata.beam, echodata.beam_power = setgrouper.set_beam()
     else:
         echodata.beam = setgrouper.set_beam()
