@@ -7,7 +7,7 @@ from .echodata import EchoData
 
 
 def open_converted(
-    converted_raw_path: "PathHint", storage_options: Dict[str, str] = None
+    converted_raw_path: "PathHint", storage_options: Dict[str, str] = None, **kwargs
 ):
     """Create an EchoData object from a single converted netcdf or zarr file.
 
@@ -17,6 +17,9 @@ def open_converted(
         path to converted data file
     storage_options : dict
         options for cloud storage
+    kwargs : dict
+        optional keyword arguments to be passed
+        into xr.open_dataset
 
     Returns
     -------
@@ -24,5 +27,7 @@ def open_converted(
     """
     # TODO: combine multiple files when opening
     return EchoData(
-        converted_raw_path=converted_raw_path, storage_options=storage_options
+        converted_raw_path=converted_raw_path,
+        storage_options=storage_options,
+        open_kwargs=kwargs,
     )
